class qtScreen : public QWidget
{
private:
	QImage	*m_img;		// shadow image

public:
	qtScreen(QWidget *parent = 0, const char *name = 0, WFlags f = 0);
	QImage *CreateShadowImage(DWORD *w, DWORD *h, int *depth, void **bits, DWORD *stride);

	//void RedrawScreen(int x, int y, int w, int h);

	//inline int depth(void) { return m_pixmap->depth(); }
	//inlien QPixmap *pixmap(void) { return m_pixmap; }

protected:
	virtual void closeEvent(QCloseEvent *e);
	virtual void paintEvent(QPaintEvent *);
	void mouseButtonEvent(QMouseEvent *ev, int type);
	virtual void mousePressEvent(QMouseEvent *);
	virtual void mouseReleaseEvent(QMouseEvent *);
	virtual void mouseMoveEvent(QMouseEvent *);
	virtual void keyPressEvent(QKeyEvent *ev);
	virtual void keyReleaseEvent(QKeyEvent *ev);
};

extern qtScreen *g_screen;
